about summary refs log tree commit diff
path: root/mach/mutex-solid.c
diff options
context:
space:
mode:
Diffstat (limited to 'mach/mutex-solid.c')
-rw-r--r--mach/mutex-solid.c7
1 files changed, 3 insertions, 4 deletions
diff --git a/mach/mutex-solid.c b/mach/mutex-solid.c
index 7ed9ce8c28..13c01fb511 100644
--- a/mach/mutex-solid.c
+++ b/mach/mutex-solid.c
@@ -17,11 +17,10 @@
    <https://www.gnu.org/licenses/>.  */
 
 #include <lock-intern.h>
-#include <cthreads.h>
 
-/* If cthreads is linked in, it will define these functions itself to do
-   real cthreads mutex locks.  This file will only be linked in when
-   cthreads is not used, and `mutexes' are in fact just spin locks (and
+/* If pthread is linked in, it will define these functions itself to do
+   real pthread mutex locks.  This file will only be linked in when
+   pthread is not used, and `mutexes' are in fact just spin locks (and
    some unused storage).  */
 
 void